@@ -10,11 +10,11 @@
 #include <QObject>
 #include <QQmlParserStatus>
 
+#include "SensorFaceController.h"
 #include "sensorfaces_export.h"
 
 namespace KSysGuard
 {
-class SensorFaceController;
 
 /**
  * A helper class to make it easier to load faces when used inside a face.
@@ -31,6 +31,7 @@ class SensorFaceController;
 class SENSORFACES_EXPORT FaceLoader : public QObject, public QQmlParserStatus
 {
     Q_OBJECT
+    QML_ELEMENT
     Q_INTERFACES(QQmlParserStatus)
     /**
      * The parent SensorFaceController that will be used for configuration storage.
